@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -34,15 +34,14 @@ sub _init {
 sub gzip {
     my ( $self, $string ) = @_;
     my $gzipped = Compress::Zlib::memGzip( $self->string() )
-      or Carp::croak("Failed to gzip HAR archive");
+      or Carp::croak('Failed to gzip HAR archive');
     return $gzipped;
 }
 
 sub string {
     my ( $self, $string ) = @_;
     my $old =
-      JSON->new()->utf8()->allow_blessed(1)->convert_blessed(1)->pretty()
-      ->encode($self);
+      JSON->new()->utf8()->allow_blessed(1)->convert_blessed(1)->pretty()->encode($self);
     if ( ( @_ > 1 ) && ( defined $string ) ) {
         $self->_init();
         my $ref = JSON->new()->utf8()->decode($string);
@@ -457,7 +456,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version '0.10'
+Version '0.11'
 
 =head1 SYNOPSIS
 
