@@ -8,7 +8,7 @@ use Archive::Har::Entry::Response();
 use Archive::Har::Entry::Cache();
 use Archive::Har::Entry::Timings();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
     my ( $class, $params ) = @_;
@@ -252,7 +252,7 @@ Archive::Har::Entry - Represents a single http request/response pair inside the
 
 =head1 VERSION
 
-Version '0.10'
+Version '0.11'
 
 =head1 SYNOPSIS
 
@@ -290,7 +290,7 @@ returns the date and time stamp for the beginning of the request (ISO 8601 forma
 
 =head2 time
 
-returns the total elapsed time of the request in milliseconds.  It is the sum of all the timings available in the timings object (not including undefined values).
+returns the total elapsed time of the request in milliseconds.  It is the sum of all the timings available in the L<timings|Archive::Har::Entry::Timings> object (not including undefined values).
 
 =head2 request
 
