@@ -5,7 +5,7 @@ use strict;
 use Carp();
 use Archive::Har::Entry::Request::PostData::Params();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
 	my ($class, $params) = @_;
@@ -13,7 +13,7 @@ sub new {
 	bless $self, $class;
 	if (defined $params) {
 		$self->mime_type($params->{mimeType});
-		if ((defined $params->{params}) && (ref $params->{params} eq 'ARRAY')) {
+		if ((defined $params->{params}) && (ref $params->{params} eq 'ARRAY') && (scalar @{$params->{params}} > 0)) {
 			my @params;
 			foreach my $param (@{$params->{params}}) {
 				push @params, Archive::Har::Entry::Request::PostData::Params->new($param);
@@ -103,9 +103,8 @@ sub TO_JSON {
 	my ($self) = @_;
 	my $json = { };
 	$json->{mimeType} = $self->mime_type();
-	if (defined $self->params()) {
-		$json->{params} = [ $self->params() ];
-	} elsif (defined $self->text()) {
+	$json->{params} = [ $self->params() ];
+	if (defined $self->text()) {
 		$json->{text} = $self->text();
 	}
 	if (defined $self->comment()) {
@@ -129,7 +128,7 @@ Archive::Har::Entry::Request::PostData - Represents a single name/value pair fro
 
 =head1 VERSION
 
-Version '0.10'
+Version '0.11'
 
 =head1 SYNOPSIS
 
