@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 sub new {
 	my ($class, $params) = @_;
@@ -74,6 +74,9 @@ sub TO_JSON {
 	my ($self) = @_;
 	my $json = { };
 	$json->{name} = $self->name();
+	if (!defined $json->{name}) {
+		$json->{name} = q[]; # HAR Viewer insists on this
+   	}
 	$json->{value} = $self->value();
 	if (defined $self->comment()) {
 		$json->{comment} = $self->comment();
@@ -95,7 +98,7 @@ Archive::Har::Entry::Request::QueryString - Represents a single name/value pair
 
 =head1 VERSION
 
-Version '0.10'
+Version '0.11'
 
 =head1 SYNOPSIS
 
